

# Read in data, load libraries --------------------------------------------

rdata <- read.csv("./Data/ReptileHRReview_LiteratureReview.csv",
                  stringsAsFactors = FALSE, na.strings = c("NA","N/A"), encoding = "UTF-8")


refdata <- read.csv("./Data/reptileHRReview_References.csv",
                    stringsAsFactors = FALSE, na.strings = c("NA","N/A"), encoding = "UTF-8")

refencesMeta <- read.csv("./Data/reptileHRReview_Metadata.csv",
                         stringsAsFactors = FALSE, na.strings = c("NA","N/A"), encoding = "UTF-8")
 

library(ggplot2)
library(ggridges)
library(raster)
library(dplyr)
library(forcats)
library(scico)
library(reshape2)
library(cowplot)
library(stringr)
library(ggrepel)
library(grid)
library(ggpubr)

methods.pal <- scico(n = 4, palette = "roma")

stderr <- function(x){
  sqrt(var(x, na.rm = TRUE)/length(x[!is.na(x)]))
}

# Clean some of the catagories --------------------------------------------

rdata$trackMethod <- trimws(rdata$trackMethod)
rdata$trackedIndi <- as.numeric(rdata$trackedIndi)

# clean up clade
# Sauria, Serpentes, Testudines, Crocodylia
rdata <- rdata %>% 
  mutate(clade.clean = case_when(
    clade %in% c("lizard", "skink", "iguana", "monitor", "varanid") ~ "Sauria",
    clade == "snake" ~ "Serpentes",
    clade %in% c("turtle", "turtle ", "tortoise") ~ "Testudines",
    clade %in% c("crocodile", "alligator") ~ "Crocodylia"
  ))

# Sample sizes overall ------------------------------------------------------------

length(unique(rdata$refID))

sum(rdata$trackedIndi, na.rm = TRUE)

max(rdata$trackedIndi, na.rm = TRUE)
min(rdata$trackedIndi, na.rm = TRUE)
mean(rdata$trackedIndi, na.rm = TRUE)
median(rdata$trackedIndi, na.rm = TRUE)
stderr(rdata$trackedIndi)

sum(is.na(rdata$trackedIndi))

# Tracking methods --------------------------------------------------------

rdata %>% 
  group_by(trackMethod) %>% 
  count()

# Tracking regimes - how variable? ----------------------------------------

rdata[rdata$minFreq > rdata$maxFreq,c("minFreq","maxFreq")]

freq.data <- rdata %>% 
  mutate(minFreq = as.numeric(trimws(minFreq)),
         maxFreq = as.numeric(trimws(maxFreq)),
         minFreq = ifelse(is.na(minFreq), -Inf, minFreq),
         maxFreq = ifelse(is.na(maxFreq), Inf, maxFreq),
         consistent = ifelse(minFreq == maxFreq, "Consistent tracking",
                             "Variable tracking"))

freq.plot.data <- freq.data %>% 
  filter(!(minFreq == -Inf & maxFreq == Inf)) %>%  
  arrange(desc(maxFreq)) 

freq.data %>% 
  group_by(trackMethod) %>% 
  filter(!(maxFreq == Inf)) %>%  
  summarise(max(maxFreq))

freq.data %>% 
  group_by(trackMethod) %>% 
  filter(!(minFreq == -Inf)) %>%  
  summarise(min(minFreq))

# number of studies with zero reporting on track freq
freq.data %>% 
  filter((minFreq == -Inf & maxFreq == Inf))
freq.data %>% 
  filter((minFreq == -Inf | maxFreq == Inf))
freq.data %>% 
  filter((minFreq == maxFreq))

rdata %>% 
  mutate(maxFreq = as.numeric(maxFreq)) %>% 
  filter(!is.na(maxFreq)) %>% 
  top_n(5, maxFreq)

reported.freq <- freq.plot.data$maxFreq[!(freq.plot.data$maxFreq ==  Inf | freq.plot.data$maxFreq ==  -Inf)]
labs.dist <- data.frame(x = round(c(min(reported.freq),
                                    # mean(reported.freq) - stderr(reported.freq),
                                    mean(reported.freq),
                                    # mean(reported.freq) + stderr(reported.freq),
                                    max(reported.freq),
                                    median(reported.freq)), digits = 2),
                        text = c("Min\n",
                                 # "-SE\n",
                                 "Mean\n",
                                 # "+SE\n",
                                 "Max\n",
                                 "Med.\n"),
                        y = rep(1.00, 4))

labs.times <- data.frame(x = c(24, 48, 96, 144, 480),
                         y = c(0.18, 0.25, 0.18, 0.25, 0.18),
                         text = c("1/hour",
                                  "2/hour",
                                  "3/hour",
                                  "6/hour",
                                  "20/hour"))

(freq.dist.plot <- ggplot() +
    geom_boxplot(aes(reported.freq), fill = "Black", width = 0.04,
                 position = position_nudge(y = -0.03), alpha = 0.75) +
    geom_rect(aes(xmin = 0, xmax = 1, ymin = -Inf, ymax = Inf),
              alpha = 0.25) +
    # geom_point(aes(reported.freq, -0.02), fill = "Black",
    #            shape = "|") +
    geom_density(aes(x = reported.freq), fill = "Black", alpha = 0.75) +
    # annotate("text", x = 500, y = Inf, label = paste(
    #   "Min =", labs.df$x[1], ", Mean =", labs.df$x[2],
    #   ", Max =", labs.df$x[3]), hjust = 1, vjust = 1,
    #   fontface = 4) +
    geom_segment(data = labs.dist, aes(x = x,
                                       xend = x,
                                       y = -0.03,
                                       yend = 1.02),
                 alpha = 0.35,
                 linetype = 1) +
    geom_text(data = filter(labs.dist,
                            x < 0.05 | x > 400),
              aes(x = x, y = y,
                  label = paste0(text,"\n",x)),
              vjust = 0.5, hjust = 1.2, fontface = 2,
              lineheight = 0.45, size = 3.5) +
    geom_text(data = filter(labs.dist,
                            x > 0.05 & x < 100),
              aes(x = x+0.5, y = y,
                  label = paste0(text,"\n",x)),
              vjust = 0.5, hjust = 0, fontface = 2,
              lineheight = 0.45, size = 3.5) +
    geom_text(data = filter(labs.times,
                            x < 240),
              aes(x = x, y = y,
                  label = text),
              vjust = 0.5, hjust = 0.5, fontface = 2,
              lineheight = 0.45, size = 3.5) +
    geom_text(data = filter(labs.times,
                            x > 240),
              aes(x = x, y = y,
                  label = text),
              vjust = 0.5, hjust = 1.1, fontface = 2,
              lineheight = 0.45, size = 3.5) +
    geom_segment(data = labs.times,
                 aes(x = x, xend = x,
                     y = 0, yend = y-0.03),
                 linetype = 2, alpha = 0.45) +
    scale_x_sqrt(breaks = c(0,1,2,6,12,24,seq(48,144,48),
                            seq(240,480,120)),
                 minor_breaks = NULL,
                 limits = c(NA,500),
                 expand = expansion(c(0, 0), c(1.4, 0.5))
    ) +
    scale_y_continuous(limits = c(NA, 1.02)) +
    labs(x = "Number of tracks per day", y = "Density") +
    theme_bw() +
    theme(axis.title = element_text(face = 2),
          axis.title.x = element_text(hjust = 1),
          axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
          axis.line.x = element_line(),
          axis.text.x = element_text(),
          panel.background = element_blank(),
          plot.margin = unit(c(1,4,0.5,2), "lines"),
          strip.text = element_text(face = 4, angle = 0, hjust = 0.5),
          panel.spacing.x = unit(0,"line"),
          strip.placement = "outside",
          # panel.grid.major.x = element_blank(),
          # panel.grid.minor.x = element_blank(),
          panel.grid = element_blank(),
          panel.border = element_blank(),
          axis.line = element_line()
    )
)

label.data.times <- data.frame(text = c("1/day", "1/2 days", "2/week", "1/week",
                                        "1/month"),
                               x = c(1,1/2,2/7,1/7,1/30.5),
                               y = rep(108, 5))

(freq.plot <- freq.plot.data %>% 
    filter(!minFreq == -Inf,
           !maxFreq == Inf) %>%
    arrange(desc(maxFreq)) %>%
    filter(minFreq<=1,
           maxFreq<=1) %>% 
    group_by(consistent) %>% 
    mutate(y = row_number()) %>% 
    ggplot() +
    geom_segment(aes(x = minFreq, xend = maxFreq, y = y, yend = y,
                     colour = clade.clean), size = 0.9) +
    geom_vline(data = label.data.times,
               aes(xintercept = x), size = 0.5, alpha = 0.25, linetype = 2) +
    geom_text(data = label.data.times,
              aes(x = x+0.005, y = y, label = text),
              size = 3.5, fontface = 2, hjust = 0) +
    # geom_point(aes(x = minFreq, y = y)) +
    scale_colour_scico_d(palette = "roma") +
    scale_x_continuous(breaks = c(1,1/2,2/7,1/7,1/30.5),
                       labels = round(c(1,1/2,2/7,1/7,1/30.5),
                                      digits = 2)) +
    coord_cartesian(xlim = c(0, 1.1),
                    ylim = c(0,112),
                    expand = 0) +
    labs(x = "Number of tracks per day", colour = "Clade") +
    theme_bw() +
    theme(axis.title = element_text(face = 2),
          axis.title.x = element_text(hjust = 1),
          axis.line.x = element_line(),
          axis.text.x = element_text(),
          axis.text.y = element_blank(),
          axis.title.y = element_blank(),
          legend.title = element_text(face = 2),
          legend.position = c(0.78, 0.75),
          axis.ticks.y = element_blank(),
          plot.margin = unit(c(1,4,0.5,2), "lines"),
          panel.spacing.x = unit(0,"line"),
          panel.grid = element_blank(),
          panel.border = element_blank(),
          axis.line = element_line()
    )
)


ggarrange(freq.dist.plot +
            theme(plot.margin = unit(c(1,0.5,0.5,2), "lines")) +
            rremove("x.title") +
            rremove("y.title") +
            rremove("y.ticks") +
            rremove("y.text"),
          freq.plot +
            theme(plot.margin = unit(c(0.5,0.5,0.01,2), "lines")),
          nrow = 2,
          align = "v",
          # common.legend = TRUE, legend = "bottom",
          heights = c(2, 2),
          labels = "AUTO")

ggsave("./Figures/Tracking regime.png", width = 210, height = 200,
       dpi = 300, units = "mm")
ggsave("./Figures/Tracking regime.pdf", width = 210, height = 200,
       units = "mm")

# Movement metrics --------------------------------------------------------

rdata %>% 
  filter(!duplicated(refID)) %>% 
  count(moveMetricTime)

# Reporting standards -----------------------------------------------------

rdata %>%
  filter(!duplicated(refID)) %>% 
  mutate(durationRepro = ifelse(durationRepro < 2,
                                 "0 or 1", ifelse(durationRepro >= 2,
                                                  "2 or higher", durationRepro))) %>% 
  group_by(durationRepro) %>% 
  count()

rdata %>%
  filter(!duplicated(refID)) %>% 
  mutate(locationsRepro = ifelse(locationsRepro < 2,
                                 "0 or 1", ifelse(locationsRepro >= 2,
                                                  "2 or higher", locationsRepro))) %>% 
  group_by(locationsRepro) %>% 
  count()

# Data links --------------------------------------------------------------

rdata %>% 
  filter(!duplicated(refID)) %>% 
  mutate(data.1 = ifelse(!data == "N", "Data link", "No data link")) %>% 
  count(data.1)

# Estimator over time ----------------------------------------

rdata %>% 
  filter(!duplicated(refID)) %>% 
  mutate(methods = ifelse(mcp == "Y" & kde == "Y", "Both",
                          ifelse(mcp == "N" & kde == "Y", "KDE",
                                 ifelse(mcp == "Y" & kde == "N", "MCP", "Other")))) %>% 
  left_join(refdata %>% 
              ungroup() %>% 
              select(refID, pubYear), by = "refID") %>% 
  group_by(pubYear) %>% 
  count()

methods.data <- rdata %>% 
  filter(!duplicated(refID)) %>% 
  mutate(methods = ifelse(mcp == "Y" & kde == "Y", "Both",
                          ifelse(mcp == "N" & kde == "Y", "KDE",
                                 ifelse(mcp == "Y" & kde == "N", "MCP", "Other")))) %>% 
  left_join(refdata %>% 
              ungroup() %>% 
              select(refID, pubYear), by = "refID") %>% 
  group_by(pubYear) %>% 
  # mutate(artYear = n()) %>%
  summarise(MCP = sum(methods == "MCP")/n()*100,
            Both = sum(methods == "Both")/n()*100,
            KDE = sum(methods == "KDE")/n()*100,
            Other = sum(methods == "Other")/n()*100
  )

methods.data

methods.area.plot <- methods.data %>% 
  melt(id = c("pubYear")) %>% 
  ggplot() +
  # geom_area(aes(x = pubYear, y = value, fill = variable),
  #           position = position_stack()) +
  geom_col(aes(x = pubYear, y = value, fill = variable),
           position = position_stack(),
           width = 0.8) +
  geom_hline(aes(yintercept = 0),
             alpha = 0.5, size = 0.5, linetype = 2) +
  annotate("text", x = 2006, y = -10,
           label = "Row & Blouin-Demers\n\"KDEs are not accurate estimators\"",
           vjust = 0.5, hjust = 0.5, lineheight = 0.75,
           fontface = 3, size = 3) +
  annotate("segment", x = 2006, xend = 2006, y = -4, yend = 0,
           arrow = arrow(length = unit(3, "mm"), type = "closed")) +
  annotate("text", x = 2012, y = -10,
           label = "Kranstauber et al.\n\"dBBMM\"",
           vjust = 0.5, hjust = 0.5, lineheight = 0.75,
           fontface = 3, size = 3) +
  annotate("segment", x = 2012, xend = 2012, y = -4, yend = 0,
           arrow = arrow(length = unit(3, "mm"), type = "closed")) +
  annotate("text", x = 2016, y = -10,
           label = "Calabrese et al.\n\"ctmm: aKDE\"",
           vjust = 0.5, hjust = 0.5, lineheight = 0.75,
           fontface = 3, size = 3) +
  annotate("segment", x = 2016, xend = 2016, y = -4, yend = 0,
           arrow = arrow(length = unit(3, "mm"), type = "closed")) +
  scale_x_continuous(breaks = seq(2000, 2019, 1),
                     limits = c(1999, NA),
                     labels = paste0("\'", sub("^..", "", as.character(seq(2000, 2019, 1)))),
                     minor_breaks = NULL
  ) +
  scale_y_continuous(limits = c(-20, 100),
                     expand = c(0,0),
                     breaks = seq(0,100,25),
                     minor_breaks = NULL) +
  geom_text(data = data.frame(x = rep(2021, 4),
                              y = c(92, 52, 18, 6),
                              method = c("MCP", "Both", "KDE", "Other")),
            aes(x = x, y = y, label = method, colour = method),
            vjust = 1, fontface = 2) +
  scale_fill_manual(values = methods.pal[c(4,2,1,3)]) +
  scale_colour_manual(values = methods.pal[c(2,1,4,3)]) +
  coord_cartesian(clip = "off", xlim = c(2000, 2019)) +
  labs(x = "Year", y = "% of\nstudies", fill = "") +
  theme_bw() +
  theme(axis.title = element_text(face = 2),
        axis.title.x = element_text(hjust = 1),
        legend.position = "none",
        axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
        plot.margin = unit(c(1,4,0.5,2), "lines"),
        strip.background = element_blank(),
        strip.text = element_text(face = 4, angle = 0, hjust = 0.5),
        panel.spacing.x = unit(0,"line"),
        strip.placement = "outside",
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line()
  )

methods.area.plot

article.count.plot <- rdata %>% 
  mutate(trackMethod = case_when(
    trackMethod %in% c("GPS") ~ "Included GPS",
    trackMethod %in% c("VHF", "automated VHF") ~ "VHF only",
    trackMethod %in% c("ultrasonic", "Satellite") ~ "Other",
    TRUE ~ trackMethod
  )) %>% 
  arrange(trackMethod) %>%
  filter(!duplicated(refID)) %>%
  mutate(methods = ifelse(mcp == "Y" & kde == "Y", "Both",
                          ifelse(mcp == "N" & kde == "Y", "KDE",
                                 ifelse(mcp == "Y" & kde == "N", "MCP", "Other"))),
         trackMethod = factor(trackMethod, c("VHF only", "Included GPS", "Other"))) %>% 
  left_join(refdata %>% 
              ungroup() %>% 
              select(refID, pubYear), by = "refID") %>% 
  group_by(pubYear, trackMethod) %>% 
  summarise(nArt = n()) %>% 
  ggplot() +
  geom_col(aes(x = pubYear, y = nArt, fill = trackMethod),
           alpha = 0.85,
           # fill = "black",
           width = 0.8) +
  scale_fill_manual(values = c("grey10", "grey30", "grey80")) +
  scale_x_continuous(breaks = seq(2000, 2019, 1),
                     limits = c(1999, 2020),
                     labels = paste0("\'", sub("^..", "",
                                               as.character(seq(2000, 2019, 1)))),
                     minor_breaks = NULL,
                     expand = c(0,0)
  ) +
  scale_y_continuous(limits = c(0, 30),
                     expand = c(0,0)) +
  labs(x = "Year", y = "Number of\nstudies", fill = "Tracking Method") +
  theme_bw() +
  theme(axis.title = element_text(face = 2),
        axis.title.x = element_text(hjust = 1),
        legend.position = c(0.135, 0.80),
        legend.title = element_blank(),
        axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
        plot.margin = unit(c(1,4,0.5,2), "lines"),
        strip.background = element_blank(),
        strip.text = element_text(face = 4, angle = 0, hjust = 0.5),
        panel.spacing.x = unit(0,"line"),
        strip.placement = "outside",
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line()
  )

article.count.plot

ggarrange(article.count.plot +
            theme(plot.margin = unit(c(1,4,0.5,2), "lines")) +
            rremove("x.text") +
            rremove("x.title") +
            rremove("x.ticks"),
          methods.area.plot +
            theme(plot.margin = unit(c(0.5,4,0.01,2), "lines")),
          nrow = 2, align = "v",
          # common.legend = TRUE, legend = "bottom",
          heights = c(1, 2),
          labels = "AUTO")

ggsave("./Figures/Temporal plot - count and methods.png", width = 190, height = 140,
       dpi = 300, units = "mm")
ggsave("./Figures/Temporal plot - count and methods.pdf", width = 190, height = 140,
       units = "mm")

# Estimator use overall ---------------------------------------------------

o.methods <- unlist(strsplit(rdata$otherMethod, "; "))
unique(o.methods[!o.methods == "N" & !is.na(o.methods)])

write.csv(o.methods, file = "./Data/Other Methods.csv",
          row.names = FALSE)

o.methods <- paste(unique(o.methods[!o.methods == "N" & !is.na(o.methods)]), collapse = "\n")

rdata %>% 
  filter(!duplicated(refID)) %>% 
  mutate(methods = ifelse(mcp == "Y" & kde == "Y", "Both",
                          ifelse(mcp == "N" & kde == "Y", "KDE",
                                 ifelse(mcp == "Y" & kde == "N", "MCP", "Other")))) %>% 
  count(methods)

rdata %>% 
  filter(!duplicated(refID)) %>% 
  mutate(methods = ifelse(mcp == "Y" & kde == "Y", "Both",
                          ifelse(mcp == "N" & kde == "Y", "KDE",
                                 ifelse(mcp == "Y" & kde == "N", "MCP", "Other")))) %>% 
  count(methods) %>% 
  filter(!is.na(methods)) %>% 
  mutate(methods = fct_reorder(methods, desc(n))) %>%
  ggplot() +
  geom_col(aes(x = methods, y = n, fill = methods), width = 0.65) +
  geom_text(aes(x = methods, y = n, 
                label = paste0(methods,"\n",
                               n)
  ),
  vjust = 1, colour = "white",
  fontface = 2, size = 6.5, hjust = 0.5, lineheight = 0.85) +
  # annotate("text", x = 4, y = 25, label = o.methods,
  #          vjust = 0, hjust = 0.5, fontface = 3) +
  scale_fill_manual(values = methods.pal[c(4,2,1,3)]) +
  scale_y_continuous(breaks = seq(0, 140, 20)) + 
  labs(x = "Home range method", y = "Count") +
  theme_bw() +
  theme(axis.title = element_text(face = 2),
        axis.title.x = element_text(hjust = 1),
        axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
        strip.background = element_blank(),
        strip.text = element_text(face = 4, angle = 0, hjust = 0.5),
        panel.spacing.x = unit(0,"line"),
        strip.placement = "outside",
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(),
        legend.position = "none")

ggsave("./Figures/Bar chart - methods.png", width = 155, height = 120,
       dpi = 300, units = "mm")
ggsave("./Figures/Bar chart - methods.pdf", width = 155, height = 120,
       units = "mm")

# Contours use -----------------------------------------

mcp.con <- trimws(unlist(strsplit(rdata$contourMCP, ";")))
mcp.con[mcp.con %in% c("UNK")] <- "NR"
mcp.df <- data.frame(con = unlist(mcp.con)) %>% 
  count(con) %>% 
  ungroup() %>% 
  mutate(tot = sum(n)) %>% 
  group_by(con) %>% 
  summarise(percent = n/tot*100) %>% 
  mutate(method = "MCP")

kde.con <- trimws(unlist(strsplit(rdata$contourKDE, ";")))
kde.con[kde.con %in% c("UNK")] <- "NR"
kde.df <- data.frame(con = unlist(kde.con)) %>% 
  count(con) %>% 
  ungroup() %>% 
  mutate(tot = sum(n)) %>% 
  group_by(con) %>% 
  summarise(percent = n/tot*100) %>% 
  mutate(method = "KDE")

contour.df <- rbind(mcp.df, kde.df)

contour.df %>% 
  mutate(con = factor(con,
                      levels = c(seq(0, 100, 5), "NR")),
         percent = as.numeric(percent),
         method = factor(method, levels = c("MCP", "KDE")),
         percent.comb = ifelse(method == "MCP", -percent, percent)) %>% 
  filter(!is.na(con)) %>% 
  ggplot() +
  geom_hline(yintercept = 0, linetype = 2, alpha = 0.25) +
  geom_segment(aes(x = con, xend = con,
                   y = 0, yend = percent.comb,
                   colour = method),
               size = 0.65) +
  geom_point(aes(x = con, y = percent.comb,
                 colour = method),
             size = 2) +
  geom_text(data = data.frame(y = c(-32, 32), x = rep(1.5, 2),
                              lab = c("MCP", "KDE")),
            aes(x = x, y = y, label = lab),
            fontface = 2, vjust = 0.5, hjust = 0.5,
            size = 6) +
  scale_colour_manual(values = methods.pal[c(4,1)]) +
  scale_y_continuous(limits = c(-40,40),
                     breaks = seq(-35,35,5),
                     labels = c(seq(35,5,-5), 0, seq(5,35,5)),
                     minor_breaks = NULL,
                     expand = c(0,0)
  ) +
  coord_flip(clip = "off") +
  labs(x = "Contour", y = "Number of Estimations", colour = "Contour") +
  theme_bw() +
  theme(axis.title = element_text(face = 2),
        axis.title.x = element_text(hjust = 0.5),
        axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
        strip.text.y = element_text(face = 4, angle = 0, vjust = 1, hjust = 1),
        strip.background = element_blank(),
        panel.spacing.x = unit(0,"line"),
        legend.position = "none",
        plot.margin = unit(c(1,4,0.5,2), "lines"),
        strip.text = element_text(face = 4, angle = 0, hjust = 0.5),
        strip.placement = "outside",
        panel.border = element_blank(),
        axis.line = element_line())

ggsave("./Figures/Chart - contours.png", width = 140, height = 90,
       dpi = 300, units = "mm")
ggsave("./Figures/Chart - contours.pdf", width = 140, height = 90,
       units = "mm")

# Smoothing Factors -------------------------------------------------------

rdata$lscv
rdata$href
rdata$rbd
rdata$unspec
unique(rdata$otherSmoothing)
# 11 others + 3 stated

rdata %>% 
  summarise(LSCV = sum(lscv == "Y", na.rm = TRUE),
            href = sum(href == "Y", na.rm = TRUE),
            `R.B-D` = sum(rbd == "Y", na.rm = TRUE),
            Other = sum(!otherSmoothing == "N" & !is.na(otherSmoothing),
                        na.rm = TRUE),
            Unspec. = sum(unspec == "Y", na.rm = TRUE)) %>% 
  mutate(total = sum(LSCV, href, `R.B-D`, Other, Unspec.))

rdata %>% 
  summarise(LSCV = sum(lscv == "Y", na.rm = TRUE),
            href = sum(href == "Y", na.rm = TRUE),
            `R.B-D` = sum(rbd == "Y", na.rm = TRUE),
            Other = sum(!otherSmoothing == "N" & !is.na(otherSmoothing),
                        na.rm = TRUE),
            Unspec. = sum(unspec == "Y", na.rm = TRUE)) %>%
  melt(value.name = "n") %>% 
  ggplot() +
  geom_col(aes(x = reorder(variable, -n), y = n),
           width = 0.8, alpha = 0.85, fill = "black") +
  geom_text(aes(x = variable, y = n, 
                label = paste0(variable,"\n",n)),
            vjust = 1, colour = "white",
            fontface = 2, size = 6, hjust = 0.5, lineheight = 0.85) +
  # scale_fill_manual(values = methods.pal[c(4,2,1,3)]) +
  scale_y_continuous(breaks = seq(0, 140, 20)) + 
  labs(x = "KDE smoothing method", y = "Count") +
  theme_bw() +
  theme(axis.title = element_text(face = 2),
        axis.title.x = element_text(hjust = 1),
        axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
        strip.background = element_blank(),
        strip.text = element_text(face = 4, angle = 0, hjust = 0.5),
        panel.spacing.x = unit(0,"line"),
        strip.placement = "outside",
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(),
        legend.position = "none")

ggsave("./Figures/Bar chart - KDE smoothing value.png", width = 165, height = 120,
       dpi = 300, units = "mm")
ggsave("./Figures/Bar chart - KDE smoothing value.pdf", width = 165, height = 120,
       units = "mm")

# Geographic patterns --------------------------------------------

rdata %>% 
  filter(!duplicated(refID)) %>% 
  count(country) %>% 
  arrange(n)

rdata %>% 
  filter(!duplicated(refID)) %>% 
  count(country) %>% 
  arrange(n) %>% 
  count(n == 1)

# we remove any extra spaces added during data entry
rdata$country <- trimws(rdata$country)

rdata <- rdata %>% 
  mutate(country = case_when(
    country %in% c("Austalia") ~ "Australia",
    country %in% c("United Kingdom") ~ "UK",
    country %in% c("Grand Cayman") ~ "Cayman Islands",
    country %in% c("Monteagudo Island") ~ "Spain",
    country %in% c("Komodo Island") ~ "Indonesia",
    country %in% c("Aldabra Atoll") ~ "Seychelles",
    country %in% c("Balearic Islands") ~ "Spain",
    TRUE ~ as.character(country)
  ))

world.map <- map_data("world")

cc <- raster::ccodes()
cc <- cc %>%
  mutate(country = case_when(
    NAME == "United Kingdom" ~ "UK",
    NAME == "United States" ~ "USA",
    NAME == "Côte d'Ivoire" ~ "Ivory Coast",
    TRUE ~ NAME
  ))

unique(rdata$country[!rdata$country %in% cc$NAME])

mapping.data <- world.map %>% 
  rename("country" = region) %>% 
  left_join(rdata %>% 
              filter(!duplicated(refID)) %>% 
              count(country)) %>% 
  left_join(cc %>% 
              dplyr::select(country, continent))

# # make sure the join is collecting all country count data
# length(unique(mapping.data$country[mapping.data$n > 0 & !is.na(mapping.data$n)]))
# unique(rdata$country)[!unique(rdata$country) %in% unique(world.map$region)]

c.areas <- unlist(lapply(unique(world.map$region), function(x){
  abs(pracma::polyarea(world.map$long[world.map$region == x],
                       world.map$lat[world.map$region == x]))
}))

country.areas <- data.frame(country = unique(world.map$region),
                            area = c.areas)
# add some labels for the small countries
highlight.data <- mapping.data %>% 
  left_join(country.areas) %>% 
  filter(area < 1, n > 0) %>% 
  group_by(country) %>% 
  summarise(mean.x = mean(long),
            mean.y = mean(lat),
            label = max(n)) %>% 
  mutate(lab.x = c(-56,
                   -60,
                   155,
                   -57,
                   -46,
                   60),
         lab.y = c(35,
                   26,
                   15,
                   21,
                   15,
                   -3))

(chloro.map <- mapping.data %>% 
    ggplot() +
    geom_polygon(aes(x = long, y = lat, group = group, fill = n),
                 # colour = "grey85",
                 size = 0.25) +
    geom_text(data = data.frame(x = c(-178,-90,90,178), y = rep(0,4)),
              aes(x = x, y = y),
              label = c(-180,-90,90,180), vjust = 0.5, hjust = 0.5,
              size = 3, colour = "grey25") +
    geom_text(data = data.frame(y = seq(-90, 90, 45), x = rep(0,5)),
              aes(x = x, y = y),
              label = seq(-90, 90, 45), vjust = 0.5, hjust = 0.5,
              size = 3, colour = "grey25") +
    geom_segment(data = highlight.data,
                 aes(x = mean.x, xend = lab.x, y = mean.y, yend = lab.y),
                 size = 0.75) +
    geom_text(data = highlight.data,
              aes(x = lab.x, y = lab.y, label = label),
              fontface = 2, hjust = 0, size = 3, vjust = 0.3) +
    scale_fill_scico(palette = "roma", na.value = "grey15",
                     # breaks = c(1, seq(20, max(mapping.data$n, na.rm = TRUE), 20)),
                     breaks = c(1,2,4,8,16,32,64,max(mapping.data$n, na.rm = TRUE)),
                     trans = "log") +
    scale_x_continuous(breaks = seq(-180, 180, 90)) +
    scale_y_continuous(breaks = seq(-90, 90, 45)) +
    coord_map(projection = "mollweide", xlim = c(-180, 180), ylim = c(-80, 90),
              clip = "off") +
    labs(x = "", y = "", fill = "Number of studies") +
    theme_minimal() +
    theme(axis.text = element_blank(),
          axis.ticks = element_blank(),
          plot.background = element_blank(),
          panel.background = element_blank(),
          panel.border = element_blank(),
          legend.title = element_text(face = 4),
          legend.position = c(0.86, -0.1),
          legend.direction = "horizontal") +
    guides(fill = guide_colourbar(title.position = "bottom", title.hjust = 0.5,
                                  ticks.colour = "black", 
                                  barwidth = 10, barheight = 0.5,
                                  ticks.linewidth = unit(1, "mm"))))

ggsave(plot = chloro.map, "./Figures/World map count.png", width = 180, height = 120,
       dpi = 300, units = "mm")

(dens.nstudies <- rdata %>% 
    count(country) %>% 
    ggplot() +
    geom_density(aes(x = n), fill = "black") +
    labs(x = "", y = "") +
    scale_x_continuous(expand = c(0,0),
                       breaks = c(1,2,4,8,16,32,64,max(mapping.data$n, na.rm = TRUE)),
                       minor_breaks = NULL, trans = "log") +
    scale_y_continuous(expand = c(0,0), breaks = NULL,
                       minor_breaks = NULL) +
    theme_bw() +
    theme(panel.background = element_blank(),
          # panel.background = element_rect(fill = "white"),
          plot.background = element_blank(),
          panel.grid = element_blank(),
          panel.border = element_blank(),
          axis.title = element_text(face = 2),
          axis.text = element_blank(),
          # axis.ticks.length.x = unit(0.5, "mm"),
          axis.ticks = element_blank(),
          axis.title.y = element_text(vjust = 1, angle = 0),
          legend.title = element_text(face = 4),
          legend.position = "bottom",
          legend.direction = "horizontal"))

ggdraw(chloro.map) +
  draw_grob(ggplotGrob(dens.nstudies),
            x = 0.70, y = 0.09, width = 0.307, height = 0.25)

ggsave("./Figures/World map count with density.png", width = 182, height = 110,
       dpi = 300, units = "mm")
ggsave("./Figures/World map count with density.pdf", width = 182, height = 110,
       units = "mm")

length(unique(rdata$country))

# Clade-wise sample sizes -------------------------------------------------

repdb <- read.csv("./Data/ReptileChecklist_2020_04.csv", stringsAsFactors = FALSE)
repdb$clade <- str_extract(repdb$Familyetc,
                           "Amphisbaenia|Serpentes|Testudines|Sauria|Crocodylia|Rhynchocephalia")

# percentage genera per clade
rdata %>% 
  mutate(genus = word(rdata$species, 1, 1)) %>% 
  group_by(genus) %>% 
  slice(n = 1) %>% 
  ungroup() %>% 
  count(clade.clean) %>% 
  left_join(repdb %>% 
              mutate(genus = word(repdb$Species, 1, 1)) %>% 
              group_by(genus) %>% 
              slice(n = 1) %>% 
              ungroup() %>% 
              count(clade) %>% 
              rename("clade.clean" = clade, "repdb" = n) %>% 
              filter(clade.clean %in% unique(rdata$clade.clean))) %>% 
  mutate(percent = n/repdb *100)

label.data <- rdata %>% 
  group_by(refID) %>% 
  summarise(species = species[1],
            clade.clean = clade.clean[1],
            trackedIndi = sum(trackedIndi, na.rm = TRUE)) %>% 
  group_by(clade.clean) %>% 
  summarise(n.indi = sum(trackedIndi, na.rm = TRUE),
            n.study = n(),
            mean.per.effort = mean(trackedIndi, na.rm = TRUE),
            se.per.effort = stderr(trackedIndi))

(by.clade.1 <- rdata %>% 
    mutate(clade.clean = factor(clade.clean,
                                levels = c(
                                  "Testudines",
                                  "Sauria",
                                  "Serpentes",
                                  "Crocodylia"
                                ))) %>%
    group_by(refID) %>% 
    summarise(species = species[1],
              clade.clean = clade.clean[1],
              trackedIndi = sum(trackedIndi, na.rm = TRUE)) %>% 
    ggplot() +
    geom_boxplot(aes(y = clade.clean, x = trackedIndi, fill = clade.clean,
                     colour = clade.clean), alpha = 0.5,
                 position = position_nudge(y = -0.125), width = 0.2) +
    geom_vline(data = data.frame(x = c(475, 570)), aes(xintercept = x),
               alpha = 0.5, size = 0.75, linetype = 2) +
    geom_segment(data = rdata %>% 
                   group_by(clade.clean) %>% 
                   summarise(max = max(trackedIndi, na.rm = TRUE)),
                 aes(y = clade.clean, yend = clade.clean,
                     x = max, xend = rep(450, 4),
                     colour = clade.clean),
                 size = 0.45, alpha = 0.5, linetype = 3) +
    geom_density_ridges(aes(x = trackedIndi, y = clade.clean,
                            fill = clade.clean, height = ..density..,
                            colour = clade.clean), alpha = 0.5,
                        # colour = NA,
                        stat = "density", trim = TRUE) +
    geom_text_repel(data = rdata %>% 
                      group_by(clade.clean) %>% 
                      top_n(2, trackedIndi) %>% 
                      filter(!clade.clean == "Crocodylia"),
                    aes(x = trackedIndi, y = clade.clean,
                        label = str_wrap(species, 8)),
                    fontface = 3, 
                    nudge_y = 0.42,
                    lineheight = 0.8,
                    size = 2.5,
                    xlim = c(45, 470)) +
    geom_text(data = label.data, aes(x = 520, y = clade.clean, 
                                     label = round(n.indi, digits = 2)),
              fontface = 3, vjust = -0.2) +
    geom_text(data = label.data, aes(x = 615, y = clade.clean, 
                                     label = round(n.study, digits = 2)),
              fontface = 3, vjust = -0.2) +
    geom_text(data = data.frame(x = c(520,615), y = rep(4.5,2),
                                text = c("Total\ntracked", "Total\nstudies")),
              aes(x = x, y = y, label = text),
              fontface = 2, hjust = 0.5, vjust = 0, lineheight = 0.8) +
    scale_x_continuous(limits = c(0, 625),
                       breaks = seq(0, 450, 50),
                       minor_breaks = seq(0, 450, 25)) +
    scale_fill_scico_d(palette = "roma", direction = -1) +
    scale_colour_scico_d(palette = "roma", direction = -1) +
    labs(x = "Tracking sample size", y = "Clade", fill = "Clade") +
    theme_bw() +
    theme(axis.title = element_text(face = 2),
          axis.title.x = element_text(hjust = 0.64),
          axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
          strip.background = element_blank(),
          strip.text = element_text(face = 4, hjust = 0),
          panel.grid.major.x = element_blank(),
          panel.grid.minor.x = element_blank(),
          panel.grid = element_blank(),
          panel.border = element_blank(),
          axis.line = element_line(),
          legend.position = "none"))

ggsave(plot = by.clade.1, "./Figures/Sample size per clade.png", width = 180,
       height = 100,
       dpi = 300, units = "mm")
ggsave(plot = by.clade.1, "./Figures/Sample size per clade.pdf", width = 180,
       height = 100, units = "mm")

# Genus-wise summary ------------------------------------------------------

genus.vec <- unlist(lapply(str_split(rdata$species, ";"), function(x){
  y <- trimws(x)
  unique(word(y, 1, 1))
  }))

length(unique(genus.vec))

rdata$genus <- trimws(word(rdata$species, 1, 1))

genus.summary <- data.frame(genus = genus.vec) %>% 
  count(genus) %>% 
  ungroup() %>% 
  left_join(rdata %>% 
              select(genus, clade.clean)) %>% 
  group_by(genus) %>% 
  slice(n = 1)

genus.summary %>% 
  arrange(desc(n))

genus.summary %>% 
  ungroup() %>% 
  count(n == 1)

other.summary <- genus.summary %>% 
  ungroup() %>% 
  filter(n <= 2) %>% 
  count(clade.clean) %>% 
  mutate(clade.clean = ifelse(clade.clean == "Crocodylia", "Croc.", clade.clean))

genus.summary <- genus.summary %>% 
  ungroup() %>% 
  mutate(genus = fct_reorder(genus, desc(n)),
         clade.clean = case_when(
           clade.clean == "Crocodylia" ~
             paste0("Croc.\n+", other.summary$n[other.summary$clade.clean == "Croc."]),
           clade.clean == "Sauria" ~
             paste0("Sauria\n+", other.summary$n[other.summary$clade.clean == "Sauria"]),
           clade.clean == "Serpentes" ~
             paste0("Serpentes\n+", other.summary$n[other.summary$clade.clean == "Serpentes"]),
           clade.clean == "Testudines" ~
             paste0("Testudines\n+", other.summary$n[other.summary$clade.clean == "Testudines"]),
                              TRUE ~ clade.clean)) %>% 
  filter(n>2)

genus.summary %>% 
  ggplot() +
  geom_col(aes(x = genus,
               y = n, fill = clade.clean), width = 0.65) +
  geom_vline(data = data.frame(x = c(20.5, 2.5, 5.5),
                               clade.clean = unique(genus.summary$clade.clean)[-3]),
             aes(xintercept = x),
             alpha = 0.5, size = 0.5, linetype = 2) +
  labs(x = "Clade | Genus", y = "Count") +
  facet_grid(.~clade.clean, scales = "free", space = "free",
             switch = "x") +
  scale_fill_scico_d(palette = "roma") +
  scale_y_continuous(breaks = seq(0, 30, 5)) +
  coord_cartesian(clip = "off") +
  theme_bw() +
  theme(axis.title = element_text(face = 2),
        axis.title.x = element_text(hjust = 1),
        axis.text.x = element_text(angle = 45, hjust = 1, size = 8,
                                   face = 3),
        axis.title.y = element_text(hjust = 1, vjust = 1, angle = 0),
        strip.background = element_blank(),
        strip.text = element_text(face = 4, angle = 0, hjust = 0.5),
        panel.spacing.x = unit(0,"line"),
        strip.placement = "outside",
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(),
        legend.position = "none")

ggsave("./Figures/Bar chart - genus.png", width = 160, height = 120,
       dpi = 300, units = "mm")
ggsave("./Figures/Bar chart - genus.pdf", width = 160, height = 120,
       units = "mm")


# Reference map of reptile diversity --------------------------------------

library(fasterize)
library(sf)

file <- list.files("./Data/GARD Ranges/", pattern = ".shp", full.names = TRUE)[1]
reptile.dist <- st_read(file)
reptile.raster <- raster(reptile.dist, res = 1/6)
reptile.raster <- fasterize(reptile.dist, reptile.raster, fun = "sum")
# plot(reptileRaster)

reptiel.dist.df <- data.frame(rasterToPoints(reptile.raster))
names(reptiel.dist.df) <- c("lon", "lat", "count")

world.poly <- map_data("world")

(rep.div.plot <- reptiel.dist.df %>% 
    ggplot() +
    geom_polygon(data = world.poly, aes(x = long, y = lat, group = group)) +
    geom_tile(aes(x = lon, y = lat, fill = count, alpha = count > 1)) +
    annotate("text", x = 0, y = -120, label = "Reptile diversity",
             fontface = 4, size = 4, hjust = 0.5, vjust = 0) +
    scale_fill_scico(palette = "lajolla", direction = -1, end = 0.8,
                     breaks = c(1, 90, 182)
                     ) +
    scale_alpha_manual(values = c(0.5, 1)) +
    labs(x = "", y = "",
         # title = "Reptile diversity",
         fill = "Number of species") +
    coord_quickmap(xlim = c(-180, 180), ylim = c(-120, 90),
                   clip = "on") +
    scale_x_continuous(breaks = seq(-180, 180, 90)) +
    scale_y_continuous(breaks = seq(-90, 90, 45)) +
    theme_minimal() +
    theme(axis.text = element_blank(),
          axis.ticks = element_blank(),
          plot.background = element_blank(),
          # panel.background = element_rect(fill = "white", colour = NA),
          panel.background = element_blank(),
          panel.border = element_blank(),
          panel.grid = element_blank(),
          legend.title = element_text(face = 4),
          # legend.position = c(0.12, 0.22),
          legend.position = "none",
          legend.direction = "horizontal",
          title = element_text(size = 8, face = 4)
    ) +
    guides(fill = guide_colourbar(title.position = "top",
                                  barheight = unit(2, "mm"),
                                  ticks.colour = "black"),
           alpha = guide_none()))

ggdraw(chloro.map) +
  draw_grob(ggplotGrob(dens.nstudies),
            x = 0.70, y = 0.09, width = 0.307, height = 0.225) +
  draw_grob(ggplotGrob(rep.div.plot),
            # x = 0.575, y = -0.05, width = 0.42, height = 0.42)
            x = -0.02, y = -0.03, width = 0.4, height = 0.4)

ggsave("./Figures/World map count with density and diversity.png", width = 182, height = 110,
       dpi = 300, units = "mm")
ggsave("./Figures/World map count with density and diversity.pdf", width = 182, height = 110,
       units = "mm")


# Summary by continent ----------------------------------------------------

cont.summary <- mapping.data %>% 
  group_by(country) %>% 
  slice(n = 1) %>% 
  group_by(continent) %>% 
  summarise(n.cont = sum(n, na.rm = TRUE))

(chloro.map.cont <- mapping.data %>% 
    left_join(cont.summary) %>% 
    ggplot() +
    geom_polygon(aes(x = long, y = lat, group = group, fill = n.cont),
                 size = 0.25) +
    geom_text(data = data.frame(x = c(-178,-90,90,178), y = rep(0,4)),
              aes(x = x, y = y),
              label = c(-180,-90,90,180), vjust = 0.5, hjust = 0.5,
              size = 3, colour = "grey25") +
    geom_text(data = data.frame(y = seq(-90, 90, 45), x = rep(0,5)),
              aes(x = x, y = y),
              label = seq(-90, 90, 45), vjust = 0.5, hjust = 0.5,
              size = 3, colour = "grey25") +
    scale_fill_scico(palette = "roma", na.value = "grey15",
                     breaks = c(0, seq(30, max(cont.summary$n.cont,
                                               na.rm = TRUE), 30))) +
    scale_x_continuous(breaks = seq(-180, 180, 90)) +
    scale_y_continuous(breaks = seq(-90, 90, 45)) +
    coord_map(projection = "mollweide", xlim = c(-180, 180), ylim = c(-80, 90),
              clip = "off") +
    labs(x = "", y = "", fill = "Number of studies") +
    theme_minimal() +
    theme(axis.text = element_blank(),
          axis.ticks = element_blank(),
          plot.background = element_blank(),
          panel.background = element_blank(),
          panel.border = element_blank(),
          legend.title = element_text(face = 4),
          legend.position = c(0.12, -0.1),
          legend.direction = "horizontal") +
    guides(fill = guide_colourbar(title.position = "top", title.hjust = 0.5,
                                  ticks.colour = "black", 
                                  barwidth = 10, barheight = 0.5,
                                  ticks.linewidth = unit(1, "mm"))))

ggsave(plot = chloro.map.cont, "./Figures/World map count by continent.png",
       width = 180, height = 120,
       dpi = 300, units = "mm")

(dens.nstudies.cont <- cont.summary %>% 
    ggplot() +
    geom_density(aes(x = n.cont), fill = "black") +
    labs(x = "", y = "") +
    scale_x_continuous(expand = c(0,0),
                       breaks = seq(1, max(cont.summary$n.cont, na.rm = TRUE), 5),
                       minor_breaks = NULL) +
    scale_y_continuous(expand = c(0,0), breaks = NULL,
                       minor_breaks = NULL) +
    theme_bw() +
    theme(panel.background = element_blank(),
          # panel.background = element_rect(fill = "white"),
          plot.background = element_blank(),
          panel.grid = element_blank(),
          panel.border = element_blank(),
          axis.title = element_text(face = 2),
          axis.text = element_blank(),
          # axis.ticks.length.x = unit(0.5, "mm"),
          axis.ticks = element_blank(),
          axis.title.y = element_text(vjust = 1, angle = 0),
          legend.title = element_text(face = 4),
          legend.position = "bottom",
          legend.direction = "horizontal"))

ggdraw(chloro.map.cont) +
  draw_grob(ggplotGrob(dens.nstudies.cont),
            x = 0.0075, y = 0.075, width = 0.295, height = 0.30)

ggsave("./Figures/World map count by continent with density.png", width = 182, height = 110,
       dpi = 300, units = "mm")

# c(813243, 812354, 812433) - 812000
# c(1645092, 1644325, 1644482) - 1644000
